@@ -26,6 +26,7 @@
 
 #include "odc/api/ColumnType.h"
 #include "eckit/sql/SQLTypedefs.h"
+#include "eckit/log/Log.h"
 
 namespace eckit { class PathName; }
 namespace eckit { class DataHandle; }
@@ -52,6 +53,27 @@ extern "C" void python_api_start()
 
 #endif
 
+
+namespace {
+
+/// @note - These functions work around a Cray 8.7 compiler bug, where
+///         where the punned version gets optimised out
+
+int64_t forceDoubleAsInteger(double v) {
+    const int64_t* punned_value = reinterpret_cast<const int64_t*>(
+                                      reinterpret_cast<const char*>(&v));
+    return *punned_value;
+}
+
+
+bool castedCompareDoublesEqual(double lhs, double rhs) {
+    int64_t lhs_val = forceDoubleAsInteger(lhs);
+    int64_t rhs_val = forceDoubleAsInteger(rhs);
+    return lhs_val == rhs_val;
+}
+} // namespace
+
+
 namespace odc {
 
 namespace core { class MetaData; }
@@ -96,8 +118,11 @@ public:
     const core::MetaData& columns(const core::MetaData& md) { return ((*it_).iter_)->columns(md); }
 	bool isNewDataset() { return ((*it_).iter_)->isNewDataset(); }
     bool isMissing(size_t i) {
-        return ((*it_).iter_)->columns()[i]->hasMissing() && ((*it_).iter_)->columns()[i]->missingValue() == (*it_)->data(i);
-	}
+        if (!((*it_).iter_)->columns()[i]->hasMissing()) return false;
+        return castedCompareDoublesEqual(
+                    ((*it_).iter_)->columns()[i]->missingValue(),
+                    (*it_)->data(i));
+    }
 	double missingValue(size_t i) { return ((*it_).iter_)->columns()[i]->missingValue(); }
     double hasMissing(size_t i) { return ((*it_).iter_)->columns()[i]->hasMissing(); }
     void flushAndResetColumnSizes(const std::map<std::string, size_t>& resetColumnSizeDoubles) {
